# Generated by roxygen2: do not edit by hand

S3method("%:=%",UnpackTarget)
S3method("%:=%",character)
S3method("%:=%",factor)
S3method("%:=%",list)
S3method("%:=%",logical)
S3method("%:=%",name)
S3method("%:=%",numeric)
S3method("%:=%",symbol)
S3method(":=",UnpackTarget)
S3method(":=",character)
S3method(":=",factor)
S3method(":=",list)
S3method(":=",logical)
S3method(":=",name)
S3method(":=",numeric)
S3method(":=",symbol)
S3method("[",Unpacker)
S3method("[<-",Unpacker)
S3method(apply_left,default)
S3method(apply_right,default)
S3method(as.character,UnpackTarget)
S3method(as.character,Unpacker)
S3method(format,UnpackTarget)
S3method(format,Unpacker)
S3method(print,UnpackTarget)
S3method(print,Unpacker)
S3method(view,data.frame)
S3method(view,default)
export("%.%")
export("%.>%")
export("%.|%")
export("%:=%")
export("%<s%")
export("%>.%")
export("%?%")
export("%c%")
export("%dot%")
export("%in_block%")
export("%p%")
export("%qc%")
export("%s>%")
export("%|.%")
export(":=")
export(DebugFn)
export(DebugFnE)
export(DebugFnW)
export(DebugFnWE)
export(DebugPrintFn)
export(DebugPrintFnE)
export(UnpackerF)
export(UnpackerP)
export(VectorizeM)
export(add_name_column)
export(apply_left)
export(apply_left_default)
export(apply_right)
export(apply_right_S4)
export(as_named_list)
export(bc)
export(bquote_call)
export(bquote_call_args)
export(bquote_function)
export(buildNameCallback)
export(build_frame)
export(checkColsFormUniqueKeys)
export(check_equiv_frames)
export(clean_fit_glm)
export(clean_fit_lm)
export(coalesce)
export(defineLambda)
export(draw_frame)
export(draw_framec)
export(evalb)
export(execute_parallel)
export(f.)
export(grab_assignments_from_dots)
export(grepdf)
export(grepv)
export(has_no_dup_rows)
export(invert_perm)
export(lambda)
export(lapplym)
export(let)
export(makeFunction_se)
export(map_to_char)
export(map_upper)
export(mapsyms)
export(match_order)
export(mk_formula)
export(mk_tmp_name_source)
export(named_map_builder)
export(orderv)
export(pack)
export(parLapplyLBm)
export(partition_tables)
export(pipe_impl)
export(psagg)
export(qae)
export(qc)
export(qchar_frame)
export(qe)
export(qs)
export(restrictToNameAssignments)
export(returnCapture)
export(seqi)
export(si)
export(sinterp)
export(sortv)
export(split_at_brace_pairs)
export(stop_if_dot_args)
export(strsplit_capture)
export(sx)
export(to)
export(uniques)
export(unpack)
export(vapplym)
export(view)
importFrom(methods,setGeneric)
importFrom(stats,lm)
importFrom(stats,update.formula)
importFrom(utils,View)
importFrom(utils,head)
